# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/model_public_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from model.model.v1alpha import model_pb2 as model_dot_model_dot_v1alpha_dot_model__pb2
from model.model.v1alpha import model_definition_pb2 as model_dot_model_dot_v1alpha_dot_model__definition__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.model/model/v1alpha/model_public_service.proto\x12\x13model.model.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x1fmodel/model/v1alpha/model.proto\x1a*model/model/v1alpha/model_definition.proto\x1a.protoc-gen-openapiv2/options/annotations.proto2\xd1k\n\x12ModelPublicService\x12\x9d\x01\n\x08Liveness\x12$.model.model.v1alpha.LivenessRequest\x1a%.model.model.v1alpha.LivenessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x13/v1alpha/__livenessZ\x17\x12\x15/v1alpha/health/model\x12\xa0\x01\n\tReadiness\x12%.model.model.v1alpha.ReadinessRequest\x1a&.model.model.v1alpha.ReadinessResponse\"D\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02.\x12\x14/v1alpha/__readinessZ\x16\x12\x14/v1alpha/ready/model\x12\xb4\x01\n\x14ListModelDefinitions\x12\x30.model.model.v1alpha.ListModelDefinitionsRequest\x1a\x31.model.model.v1alpha.ListModelDefinitionsResponse\"7\x92\x41\x12\n\x10Model Definition\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1alpha/model-definitions\x12\xaa\x01\n\x14ListAvailableRegions\x12\x30.model.model.v1alpha.ListAvailableRegionsRequest\x1a\x31.model.model.v1alpha.ListAvailableRegionsResponse\"-\x92\x41\x08\n\x06Region\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1alpha/available-regions\x12\xc4\x01\n\x12GetModelDefinition\x12..model.model.v1alpha.GetModelDefinitionRequest\x1a/.model.model.v1alpha.GetModelDefinitionResponse\"M\x92\x41\x12\n\x10Model Definition\x82\xd3\xe4\x93\x02\x32\x12\x30/v1alpha/model-definitions/{model_definition_id}\x12\x80\x01\n\nListModels\x12&.model.model.v1alpha.ListModelsRequest\x1a\'.model.model.v1alpha.ListModelsResponse\"!\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/models\x12\xa8\x01\n\x0bLookUpModel\x12\'.model.model.v1alpha.LookUpModelRequest\x1a(.model.model.v1alpha.LookUpModelResponse\"F\x92\x41\x07\n\x05Model\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02&\x12$/v1alpha/{permalink=models/*}/lookUp\x12\xb5\x01\n\x13ListNamespaceModels\x12/.model.model.v1alpha.ListNamespaceModelsRequest\x1a\x30.model.model.v1alpha.ListNamespaceModelsResponse\";\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02+\x12)/v1alpha/namespaces/{namespace_id}/models\x12\xbf\x01\n\x14\x43reateNamespaceModel\x12\x30.model.model.v1alpha.CreateNamespaceModelRequest\x1a\x31.model.model.v1alpha.CreateNamespaceModelResponse\"B\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x32\")/v1alpha/namespaces/{namespace_id}/models:\x05model\x12\xba\x01\n\x11GetNamespaceModel\x12-.model.model.v1alpha.GetNamespaceModelRequest\x1a..model.model.v1alpha.GetNamespaceModelResponse\"F\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x36\x12\x34/v1alpha/namespaces/{namespace_id}/models/{model_id}\x12\xca\x01\n\x14UpdateNamespaceModel\x12\x30.model.model.v1alpha.UpdateNamespaceModelRequest\x1a\x31.model.model.v1alpha.UpdateNamespaceModelResponse\"M\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02=24/v1alpha/namespaces/{namespace_id}/models/{model_id}:\x05model\x12\xc3\x01\n\x14\x44\x65leteNamespaceModel\x12\x30.model.model.v1alpha.DeleteNamespaceModelRequest\x1a\x31.model.model.v1alpha.DeleteNamespaceModelResponse\"F\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02\x36*4/v1alpha/namespaces/{namespace_id}/models/{model_id}\x12\xcd\x01\n\x14RenameNamespaceModel\x12\x30.model.model.v1alpha.RenameNamespaceModelRequest\x1a\x31.model.model.v1alpha.RenameNamespaceModelResponse\"P\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02@\";/v1alpha/namespaces/{namespace_id}/models/{model_id}/rename:\x01*\x12\xdb\x01\n\x13WatchNamespaceModel\x12/.model.model.v1alpha.WatchNamespaceModelRequest\x1a\x30.model.model.v1alpha.WatchNamespaceModelResponse\"a\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02O\x12M/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/watch\x12\xd8\x01\n\x19WatchNamespaceLatestModel\x12\x35.model.model.v1alpha.WatchNamespaceLatestModelRequest\x1a\x36.model.model.v1alpha.WatchNamespaceLatestModelResponse\"L\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02<\x12:/v1alpha/namespaces/{namespace_id}/models/{model_id}/watch\x12\xe0\x01\n\x1aListNamespaceModelVersions\x12\x36.model.model.v1alpha.ListNamespaceModelVersionsRequest\x1a\x37.model.model.v1alpha.ListNamespaceModelVersionsResponse\"Q\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02?\x12=/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions\x12\xed\x01\n\x1b\x44\x65leteNamespaceModelVersion\x12\x37.model.model.v1alpha.DeleteNamespaceModelVersionRequest\x1a\x38.model.model.v1alpha.DeleteNamespaceModelVersionResponse\"[\x92\x41\t\n\x07Version\x82\xd3\xe4\x93\x02I*G/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}\x12\x8b\x03\n\x15TriggerNamespaceModel\x12\x31.model.model.v1alpha.TriggerNamespaceModelRequest\x1a\x32.model.model.v1alpha.TriggerNamespaceModelResponse\"\x8a\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02T\"O/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger:\x01*\x12\xa0\x03\n\x1aTriggerAsyncNamespaceModel\x12\x36.model.model.v1alpha.TriggerAsyncNamespaceModelRequest\x1a\x37.model.model.v1alpha.TriggerAsyncNamespaceModelResponse\"\x90\x02\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02Z\"U/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger-async:\x01*\x12\x8a\x03\n\x1bTriggerNamespaceLatestModel\x12\x37.model.model.v1alpha.TriggerNamespaceLatestModelRequest\x1a\x38.model.model.v1alpha.TriggerNamespaceLatestModelResponse\"\xf7\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02\x41\"</v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger:\x01*\x12\x9f\x03\n TriggerAsyncNamespaceLatestModel\x12<.model.model.v1alpha.TriggerAsyncNamespaceLatestModelRequest\x1a=.model.model.v1alpha.TriggerAsyncNamespaceLatestModelResponse\"\xfd\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02G\"B/v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger-async:\x01*\x12\xdd\x02\n%TriggerNamespaceModelBinaryFileUpload\x12\x41.model.model.v1alpha.TriggerNamespaceModelBinaryFileUploadRequest\x1a\x42.model.model.v1alpha.TriggerNamespaceModelBinaryFileUploadResponse\"\xaa\x01\x92\x41\xa6\x01\n\x07Triggerr\x9a\x01\n\x97\x01\n\x15Instill-Requester-Uid\x12|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\x18\x01(\x01\x12\xef\x02\n+TriggerNamespaceLatestModelBinaryFileUpload\x12G.model.model.v1alpha.TriggerNamespaceLatestModelBinaryFileUploadRequest\x1aH.model.model.v1alpha.TriggerNamespaceLatestModelBinaryFileUploadResponse\"\xaa\x01\x92\x41\xa6\x01\n\x07Triggerr\x9a\x01\n\x97\x01\n\x15Instill-Requester-Uid\x12|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\x18\x01(\x01\x12\xf2\x01\n\x1aGetNamespaceModelOperation\x12\x36.model.model.v1alpha.GetNamespaceModelOperationRequest\x1a\x37.model.model.v1alpha.GetNamespaceModelOperationResponse\"c\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02S\x12Q/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/operation\x12\xf1\x01\n GetNamespaceLatestModelOperation\x12<.model.model.v1alpha.GetNamespaceLatestModelOperationRequest\x1a=.model.model.v1alpha.GetNamespaceLatestModelOperationResponse\"P\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02@\x12>/v1alpha/namespaces/{namespace_id}/models/{model_id}/operation\x12\xa8\x01\n\x11GetModelOperation\x12-.model.model.v1alpha.GetModelOperationRequest\x1a..model.model.v1alpha.GetModelOperationResponse\"4\x92\x41\x07\n\x05Model\x82\xd3\xe4\x93\x02$\x12\"/v1alpha/operations/{operation_id}\x12\xa6\x01\n\x0eListUserModels\x12*.model.model.v1alpha.ListUserModelsRequest\x1a+.model.model.v1alpha.ListUserModelsResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{parent=users/*}/models\x12\xb0\x01\n\x0f\x43reateUserModel\x12+.model.model.v1alpha.CreateUserModelRequest\x1a,.model.model.v1alpha.CreateUserModelResponse\"B\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02)\" /v1alpha/{parent=users/*}/models:\x05model\x12\xa0\x01\n\x0cGetUserModel\x12(.model.model.v1alpha.GetUserModelRequest\x1a).model.model.v1alpha.GetUserModelResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"\x12 /v1alpha/{name=users/*/models/*}\x12\xb6\x01\n\x0fUpdateUserModel\x12+.model.model.v1alpha.UpdateUserModelRequest\x1a,.model.model.v1alpha.UpdateUserModelResponse\"H\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02/2&/v1alpha/{model.name=users/*/models/*}:\x05model\x12\xa9\x01\n\x0f\x44\x65leteUserModel\x12+.model.model.v1alpha.DeleteUserModelRequest\x1a,.model.model.v1alpha.DeleteUserModelResponse\";\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\"* /v1alpha/{name=users/*/models/*}\x12\xb3\x01\n\x0fRenameUserModel\x12+.model.model.v1alpha.RenameUserModelRequest\x1a,.model.model.v1alpha.RenameUserModelResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\"\'/v1alpha/{name=users/*/models/*}/rename:\x01*\x12\xc1\x01\n\x0eWatchUserModel\x12*.model.model.v1alpha.WatchUserModelRequest\x1a+.model.model.v1alpha.WatchUserModelResponse\"V\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02=\x12;/v1alpha/{name=users/*/models/*}/versions/{version=*}/watch\x12\xbe\x01\n\x14WatchUserLatestModel\x12\x30.model.model.v1alpha.WatchUserLatestModelRequest\x1a\x31.model.model.v1alpha.WatchUserLatestModelResponse\"A\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02(\x12&/v1alpha/{name=users/*/models/*}/watch\x12\xc4\x01\n\x15ListUserModelVersions\x12\x31.model.model.v1alpha.ListUserModelVersionsRequest\x1a\x32.model.model.v1alpha.ListUserModelVersionsResponse\"D\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02+\x12)/v1alpha/{name=users/*/models/*}/versions\x12\xd3\x01\n\x16\x44\x65leteUserModelVersion\x12\x32.model.model.v1alpha.DeleteUserModelVersionRequest\x1a\x33.model.model.v1alpha.DeleteUserModelVersionResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37*5/v1alpha/{name=users/*/models/*}/versions/{version=*}\x12\xcc\x01\n\x10TriggerUserModel\x12,.model.model.v1alpha.TriggerUserModelRequest\x1a-.model.model.v1alpha.TriggerUserModelResponse\"[\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x42\"=/v1alpha/{name=users/*/models/*}/versions/{version=*}/trigger:\x01*\x12\xe0\x01\n\x15TriggerAsyncUserModel\x12\x31.model.model.v1alpha.TriggerAsyncUserModelRequest\x1a\x32.model.model.v1alpha.TriggerAsyncUserModelResponse\"`\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02G\"B/v1alpha/{name=users/*/models/*}/versions/{version=*}/triggerAsync:\x01*\x12\xc9\x01\n\x16TriggerUserLatestModel\x12\x32.model.model.v1alpha.TriggerUserLatestModelRequest\x1a\x33.model.model.v1alpha.TriggerUserLatestModelResponse\"F\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02-\"(/v1alpha/{name=users/*/models/*}/trigger:\x01*\x12\xdd\x01\n\x1bTriggerAsyncUserLatestModel\x12\x37.model.model.v1alpha.TriggerAsyncUserLatestModelRequest\x1a\x38.model.model.v1alpha.TriggerAsyncUserLatestModelResponse\"K\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x32\"-/v1alpha/{name=users/*/models/*}/triggerAsync:\x01*\x12\xb6\x01\n TriggerUserModelBinaryFileUpload\x12<.model.model.v1alpha.TriggerUserModelBinaryFileUploadRequest\x1a=.model.model.v1alpha.TriggerUserModelBinaryFileUploadResponse\"\x13\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL(\x01\x12\xc6\x01\n\x16ListOrganizationModels\x12\x32.model.model.v1alpha.ListOrganizationModelsRequest\x1a\x33.model.model.v1alpha.ListOrganizationModelsResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{parent=organizations/*}/models\x12\xd0\x01\n\x17\x43reateOrganizationModel\x12\x33.model.model.v1alpha.CreateOrganizationModelRequest\x1a\x34.model.model.v1alpha.CreateOrganizationModelResponse\"J\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x31\"(/v1alpha/{parent=organizations/*}/models:\x05model\x12\xc0\x01\n\x14GetOrganizationModel\x12\x30.model.model.v1alpha.GetOrganizationModelRequest\x1a\x31.model.model.v1alpha.GetOrganizationModelResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02*\x12(/v1alpha/{name=organizations/*/models/*}\x12\xd6\x01\n\x17UpdateOrganizationModel\x12\x33.model.model.v1alpha.UpdateOrganizationModelRequest\x1a\x34.model.model.v1alpha.UpdateOrganizationModelResponse\"P\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x37\x32./v1alpha/{model.name=organizations/*/models/*}:\x05model\x12\xc9\x01\n\x17\x44\x65leteOrganizationModel\x12\x33.model.model.v1alpha.DeleteOrganizationModelRequest\x1a\x34.model.model.v1alpha.DeleteOrganizationModelResponse\"C\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02**(/v1alpha/{name=organizations/*/models/*}\x12\xd3\x01\n\x17RenameOrganizationModel\x12\x33.model.model.v1alpha.RenameOrganizationModelRequest\x1a\x34.model.model.v1alpha.RenameOrganizationModelResponse\"M\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x34\"//v1alpha/{name=organizations/*/models/*}/rename:\x01*\x12\xe1\x01\n\x16WatchOrganizationModel\x12\x32.model.model.v1alpha.WatchOrganizationModelRequest\x1a\x33.model.model.v1alpha.WatchOrganizationModelResponse\"^\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x45\x12\x43/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/watch\x12\xde\x01\n\x1cWatchOrganizationLatestModel\x12\x38.model.model.v1alpha.WatchOrganizationLatestModelRequest\x1a\x39.model.model.v1alpha.WatchOrganizationLatestModelResponse\"I\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x30\x12./v1alpha/{name=organizations/*/models/*}/watch\x12\xe4\x01\n\x1dListOrganizationModelVersions\x12\x39.model.model.v1alpha.ListOrganizationModelVersionsRequest\x1a:.model.model.v1alpha.ListOrganizationModelVersionsResponse\"L\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x33\x12\x31/v1alpha/{name=organizations/*/models/*}/versions\x12\xf3\x01\n\x1e\x44\x65leteOrganizationModelVersion\x12:.model.model.v1alpha.DeleteOrganizationModelVersionRequest\x1a;.model.model.v1alpha.DeleteOrganizationModelVersionResponse\"X\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02?*=/v1alpha/{name=organizations/*/models/*}/versions/{version=*}\x12\xec\x01\n\x18TriggerOrganizationModel\x12\x34.model.model.v1alpha.TriggerOrganizationModelRequest\x1a\x35.model.model.v1alpha.TriggerOrganizationModelResponse\"c\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02J\"E/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/trigger:\x01*\x12\x80\x02\n\x1dTriggerAsyncOrganizationModel\x12\x39.model.model.v1alpha.TriggerAsyncOrganizationModelRequest\x1a:.model.model.v1alpha.TriggerAsyncOrganizationModelResponse\"h\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02O\"J/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/triggerAsync:\x01*\x12\xe9\x01\n\x1eTriggerOrganizationLatestModel\x12:.model.model.v1alpha.TriggerOrganizationLatestModelRequest\x1a;.model.model.v1alpha.TriggerOrganizationLatestModelResponse\"N\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x35\"0/v1alpha/{name=organizations/*/models/*}/trigger:\x01*\x12\xfd\x01\n#TriggerAsyncOrganizationLatestModel\x12?.model.model.v1alpha.TriggerAsyncOrganizationLatestModelRequest\x1a@.model.model.v1alpha.TriggerAsyncOrganizationLatestModelResponse\"S\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02:\"5/v1alpha/{name=organizations/*/models/*}/triggerAsync:\x01*\x12\xce\x01\n(TriggerOrganizationModelBinaryFileUpload\x12\x44.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadRequest\x1a\x45.model.model.v1alpha.TriggerOrganizationModelBinaryFileUploadResponse\"\x13\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL(\x01\x12\xd7\x01\n\x1bGetUserLatestModelOperation\x12\x37.model.model.v1alpha.GetUserLatestModelOperationRequest\x1a\x38.model.model.v1alpha.GetUserLatestModelOperationResponse\"E\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02,\x12*/v1alpha/{name=users/*/models/*}/operation\x12\xf7\x01\n#GetOrganizationLatestModelOperation\x12?.model.model.v1alpha.GetOrganizationLatestModelOperationRequest\x1a@.model.model.v1alpha.GetOrganizationLatestModelOperationResponse\"M\x88\x02\x01\xfa\xd2\xe4\x93\x02\n\x12\x08INTERNAL\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/{name=organizations/*/models/*}/operation\x12\xda\x02\n\rListModelRuns\x12).model.model.v1alpha.ListModelRunsRequest\x1a*.model.model.v1alpha.ListModelRunsResponse\"\xf1\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02;\x12\x39/v1alpha/namespaces/{namespace_id}/models/{model_id}/runs\x12\xe6\x02\n\x1aListModelRunsByCreditOwner\x12\x36.model.model.v1alpha.ListModelRunsByCreditOwnerRequest\x1a\x37.model.model.v1alpha.ListModelRunsByCreditOwnerResponse\"\xd6\x01\x92\x41\xac\x01\n\x07Triggerr\xa0\x01\n\x9d\x01\n\x15Instill-Requester-Uid\x12\x81\x01Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\x18\x01\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/dashboard/models/runs\x1a\x1b\x92\x41\x18\x12\x16Public Model endpointsB\xe4\x01\n\x17\x63om.model.model.v1alphaB\x17ModelPublicServiceProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.model_public_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\027ModelPublicServiceProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _MODELPUBLICSERVICE._options = None
  _MODELPUBLICSERVICE._serialized_options = b'\222A\030\022\026Public Model endpoints'
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Liveness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\023/v1alpha/__livenessZ\027\022\025/v1alpha/health/model'
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._options = None
  _MODELPUBLICSERVICE.methods_by_name['Readiness']._serialized_options = b'\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002.\022\024/v1alpha/__readinessZ\026\022\024/v1alpha/ready/model'
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelDefinitions']._serialized_options = b'\222A\022\n\020Model Definition\202\323\344\223\002\034\022\032/v1alpha/model-definitions'
  _MODELPUBLICSERVICE.methods_by_name['ListAvailableRegions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListAvailableRegions']._serialized_options = b'\222A\010\n\006Region\202\323\344\223\002\034\022\032/v1alpha/available-regions'
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelDefinition']._serialized_options = b'\222A\022\n\020Model Definition\202\323\344\223\0022\0220/v1alpha/model-definitions/{model_definition_id}'
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModels']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002\021\022\017/v1alpha/models'
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['LookUpModel']._serialized_options = b'\222A\007\n\005Model\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002&\022$/v1alpha/{permalink=models/*}/lookUp'
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModels']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002+\022)/v1alpha/namespaces/{namespace_id}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0022\")/v1alpha/namespaces/{namespace_id}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0026\0224/v1alpha/namespaces/{namespace_id}/models/{model_id}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002=24/v1alpha/namespaces/{namespace_id}/models/{model_id}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\0026*4/v1alpha/namespaces/{namespace_id}/models/{model_id}'
  _MODELPUBLICSERVICE.methods_by_name['RenameNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameNamespaceModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002@\";/v1alpha/namespaces/{namespace_id}/models/{model_id}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceModel']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002O\022M/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchNamespaceLatestModel']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002<\022:/v1alpha/namespaces/{namespace_id}/models/{model_id}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListNamespaceModelVersions']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002?\022=/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteNamespaceModelVersion']._serialized_options = b'\222A\t\n\007Version\202\323\344\223\002I*G/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002T\"O/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002Z\"U/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/trigger-async:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002A\"</v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncNamespaceLatestModel']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002G\"B/v1alpha/namespaces/{namespace_id}/models/{model_id}/trigger-async:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceModelBinaryFileUpload']._serialized_options = b'\222A\246\001\n\007Triggerr\232\001\n\227\001\n\025Instill-Requester-Uid\022|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\030\001'
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerNamespaceLatestModelBinaryFileUpload']._serialized_options = b'\222A\246\001\n\007Triggerr\232\001\n\227\001\n\025Instill-Requester-Uid\022|Indicates the authenticated user is making the request on behalf of another entity, typically an organization they belong to\030\001'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002S\022Q/v1alpha/namespaces/{namespace_id}/models/{model_id}/versions/{version}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetNamespaceLatestModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002@\022>/v1alpha/namespaces/{namespace_id}/models/{model_id}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetModelOperation']._serialized_options = b'\222A\007\n\005Model\202\323\344\223\002$\022\"/v1alpha/operations/{operation_id}'
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListUserModels']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1alpha/{parent=users/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002)\" /v1alpha/{parent=users/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"\022 /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002/2&/v1alpha/{model.name=users/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002\"* /v1alpha/{name=users/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\"\'/v1alpha/{name=users/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002=\022;/v1alpha/{name=users/*/models/*}/versions/{version=*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002(\022&/v1alpha/{name=users/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListUserModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListUserModelVersions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002+\022)/v1alpha/{name=users/*/models/*}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteUserModelVersion']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0027*5/v1alpha/{name=users/*/models/*}/versions/{version=*}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002B\"=/v1alpha/{name=users/*/models/*}/versions/{version=*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002G\"B/v1alpha/{name=users/*/models/*}/versions/{version=*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002-\"(/v1alpha/{name=users/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncUserLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0022\"-/v1alpha/{name=users/*/models/*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerUserModelBinaryFileUpload']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL'
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModels']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1alpha/{parent=organizations/*}/models'
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['CreateOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0021\"(/v1alpha/{parent=organizations/*}/models:\005model'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002*\022(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['UpdateOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\00272./v1alpha/{model.name=organizations/*/models/*}:\005model'
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002**(/v1alpha/{name=organizations/*/models/*}'
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['RenameOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0024\"//v1alpha/{name=organizations/*/models/*}/rename:\001*'
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002E\022C/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['WatchOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0020\022./v1alpha/{name=organizations/*/models/*}/watch'
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModelVersions']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListOrganizationModelVersions']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0023\0221/v1alpha/{name=organizations/*/models/*}/versions'
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModelVersion']._options = None
  _MODELPUBLICSERVICE.methods_by_name['DeleteOrganizationModelVersion']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002?*=/v1alpha/{name=organizations/*/models/*}/versions/{version=*}'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002J\"E/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002O\"J/v1alpha/{name=organizations/*/models/*}/versions/{version=*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0025\"0/v1alpha/{name=organizations/*/models/*}/trigger:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationLatestModel']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerAsyncOrganizationLatestModel']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002:\"5/v1alpha/{name=organizations/*/models/*}/triggerAsync:\001*'
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._options = None
  _MODELPUBLICSERVICE.methods_by_name['TriggerOrganizationModelBinaryFileUpload']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL'
  _MODELPUBLICSERVICE.methods_by_name['GetUserLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetUserLatestModelOperation']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\002,\022*/v1alpha/{name=users/*/models/*}/operation'
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationLatestModelOperation']._options = None
  _MODELPUBLICSERVICE.methods_by_name['GetOrganizationLatestModelOperation']._serialized_options = b'\210\002\001\372\322\344\223\002\n\022\010INTERNAL\202\323\344\223\0024\0222/v1alpha/{name=organizations/*/models/*}/operation'
  _MODELPUBLICSERVICE.methods_by_name['ListModelRuns']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelRuns']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002;\0229/v1alpha/namespaces/{namespace_id}/models/{model_id}/runs'
  _MODELPUBLICSERVICE.methods_by_name['ListModelRunsByCreditOwner']._options = None
  _MODELPUBLICSERVICE.methods_by_name['ListModelRunsByCreditOwner']._serialized_options = b'\222A\254\001\n\007Triggerr\240\001\n\235\001\n\025Instill-Requester-Uid\022\201\001Indicates the authenticated namespace is making the request on behalf of another entity, typically an organization they belong to\030\001\202\323\344\223\002 \022\036/v1alpha/dashboard/models/runs'
  _globals['_MODELPUBLICSERVICE']._serialized_start=256
  _globals['_MODELPUBLICSERVICE']._serialized_end=14033
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RunStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RunStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RunStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RUN_STATUS_UNSPECIFIED: _RunStatus.ValueType  # 0
    """Unspecified."""
    RUN_STATUS_PROCESSING: _RunStatus.ValueType  # 1
    """Run in progress."""
    RUN_STATUS_COMPLETED: _RunStatus.ValueType  # 2
    """Run succeeded."""
    RUN_STATUS_FAILED: _RunStatus.ValueType  # 3
    """Run failed."""
    RUN_STATUS_QUEUED: _RunStatus.ValueType  # 4
    """Run is waiting to be executed."""

class RunStatus(_RunStatus, metaclass=_RunStatusEnumTypeWrapper):
    """RunStatus defines the status of a pipeline or model run."""

RUN_STATUS_UNSPECIFIED: RunStatus.ValueType  # 0
"""Unspecified."""
RUN_STATUS_PROCESSING: RunStatus.ValueType  # 1
"""Run in progress."""
RUN_STATUS_COMPLETED: RunStatus.ValueType  # 2
"""Run succeeded."""
RUN_STATUS_FAILED: RunStatus.ValueType  # 3
"""Run failed."""
RUN_STATUS_QUEUED: RunStatus.ValueType  # 4
"""Run is waiting to be executed."""
global___RunStatus = RunStatus

class _RunSource:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RunSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RunSource.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RUN_SOURCE_UNSPECIFIED: _RunSource.ValueType  # 0
    """Unspecified."""
    RUN_SOURCE_CONSOLE: _RunSource.ValueType  # 1
    """Run from frontend UI."""
    RUN_SOURCE_API: _RunSource.ValueType  # 2
    """Run from API or SDK."""

class RunSource(_RunSource, metaclass=_RunSourceEnumTypeWrapper):
    """RunSource defines the source of a pipeline or model run."""

RUN_SOURCE_UNSPECIFIED: RunSource.ValueType  # 0
"""Unspecified."""
RUN_SOURCE_CONSOLE: RunSource.ValueType  # 1
"""Run from frontend UI."""
RUN_SOURCE_API: RunSource.ValueType  # 2
"""Run from API or SDK."""
global___RunSource = RunSource



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import artifact.artifact.v1alpha.chunk_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class QuestionAnsweringRequest(google.protobuf.message.Message):
    """QuestionAnsweringRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    QUESTION_FIELD_NUMBER: builtins.int
    TOP_K_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """id of the namespace"""
    catalog_id: builtins.str
    """id of the catalog"""
    question: builtins.str
    """question to be answered"""
    top_k: builtins.int
    """top k default to 5"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        question: builtins.str = ...,
        top_k: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "namespace_id", b"namespace_id", "question", b"question", "top_k", b"top_k"]) -> None: ...

global___QuestionAnsweringRequest = QuestionAnsweringRequest

@typing_extensions.final
class QuestionAnsweringResponse(google.protobuf.message.Message):
    """QuestionAnsweringResponse"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANSWER_FIELD_NUMBER: builtins.int
    SIMILAR_CHUNKS_FIELD_NUMBER: builtins.int
    answer: builtins.str
    """answer to the question"""
    @property
    def similar_chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunk]:
        """chunks"""
    def __init__(
        self,
        *,
        answer: builtins.str = ...,
        similar_chunks: collections.abc.Iterable[artifact.artifact.v1alpha.chunk_pb2.SimilarityChunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["answer", b"answer", "similar_chunks", b"similar_chunks"]) -> None: ...

global___QuestionAnsweringResponse = QuestionAnsweringResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&artifact/artifact/v1alpha/object.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xf9\x03\n\x06Object\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x12\n\x04size\x18\x03 \x01(\x03R\x04size\x12!\n\x0c\x63ontent_type\x18\x04 \x01(\tR\x0b\x63ontentType\x12#\n\rnamespace_uid\x18\x06 \x01(\tR\x0cnamespaceUid\x12\x18\n\x07\x63reator\x18\x07 \x01(\tR\x07\x63reator\x12\x1f\n\x0bis_uploaded\x18\x08 \x01(\x08R\nisUploaded\x12\x17\n\x04path\x18\t \x01(\tH\x00R\x04path\x88\x01\x01\x12,\n\x12object_expire_days\x18\n \x01(\x05R\x10objectExpireDays\x12M\n\x12last_modified_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01R\x10lastModifiedTime\x88\x01\x01\x12=\n\x0c\x63reated_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0b\x63reatedTime\x12=\n\x0cupdated_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bupdatedTimeB\x07\n\x05_pathB\x15\n\x13_last_modified_time\"\x98\x02\n\x19GetObjectUploadURLRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12$\n\x0bobject_name\x18\x02 \x01(\tB\x03\xe0\x41\x02R\nobjectName\x12+\n\x0furl_expire_days\x18\x03 \x01(\x05\x42\x03\xe0\x41\x01R\rurlExpireDays\x12M\n\x12last_modified_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x01R\x10lastModifiedTime\x12\x31\n\x12object_expire_days\x18\x05 \x01(\x05\x42\x03\xe0\x41\x01R\x10objectExpireDays\"\xb6\x01\n\x1aGetObjectUploadURLResponse\x12\x1d\n\nupload_url\x18\x01 \x01(\tR\tuploadUrl\x12>\n\rurl_expire_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0burlExpireAt\x12\x39\n\x06object\x18\x03 \x01(\x0b\x32!.artifact.artifact.v1alpha.ObjectR\x06object\"\xbc\x01\n\x1bGetObjectDownloadURLRequest\x12&\n\x0cnamespace_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\x0bnamespaceId\x12\"\n\nobject_uid\x18\x02 \x01(\tB\x03\xe0\x41\x01R\tobjectUid\x12$\n\x0bobject_name\x18\x03 \x01(\tB\x03\xe0\x41\x01R\nobjectName\x12+\n\x0furl_expire_days\x18\x04 \x01(\x05\x42\x03\xe0\x41\x01R\rurlExpireDays\"\xbc\x01\n\x1cGetObjectDownloadURLResponse\x12!\n\x0c\x64ownload_url\x18\x01 \x01(\tR\x0b\x64ownloadUrl\x12>\n\rurl_expire_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0burlExpireAt\x12\x39\n\x06object\x18\x04 \x01(\x0b\x32!.artifact.artifact.v1alpha.ObjectR\x06objectB\xff\x01\n\x1d\x63om.artifact.artifact.v1alphaB\x0bObjectProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\013ObjectProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['namespace_id']._options = None
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['object_name']._options = None
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['object_name']._serialized_options = b'\340A\002'
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['url_expire_days']._options = None
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['url_expire_days']._serialized_options = b'\340A\001'
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['last_modified_time']._options = None
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['last_modified_time']._serialized_options = b'\340A\001'
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['object_expire_days']._options = None
  _GETOBJECTUPLOADURLREQUEST.fields_by_name['object_expire_days']._serialized_options = b'\340A\001'
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['namespace_id']._options = None
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['namespace_id']._serialized_options = b'\340A\002'
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['object_uid']._options = None
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['object_uid']._serialized_options = b'\340A\001'
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['object_name']._options = None
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['object_name']._serialized_options = b'\340A\001'
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['url_expire_days']._options = None
  _GETOBJECTDOWNLOADURLREQUEST.fields_by_name['url_expire_days']._serialized_options = b'\340A\001'
  _globals['_OBJECT']._serialized_start=136
  _globals['_OBJECT']._serialized_end=641
  _globals['_GETOBJECTUPLOADURLREQUEST']._serialized_start=644
  _globals['_GETOBJECTUPLOADURLREQUEST']._serialized_end=924
  _globals['_GETOBJECTUPLOADURLRESPONSE']._serialized_start=927
  _globals['_GETOBJECTUPLOADURLRESPONSE']._serialized_end=1109
  _globals['_GETOBJECTDOWNLOADURLREQUEST']._serialized_start=1112
  _globals['_GETOBJECTDOWNLOADURLREQUEST']._serialized_end=1300
  _globals['_GETOBJECTDOWNLOADURLRESPONSE']._serialized_start=1303
  _globals['_GETOBJECTDOWNLOADURLRESPONSE']._serialized_end=1491
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.mgmt.v1beta import metric_pb2 as core_dot_mgmt_dot_v1beta_dot_metric__pb2
from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2


class MgmtPublicServiceStub(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/Liveness',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/Readiness',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.FromString,
                )
        self.GetAuthenticatedUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.FromString,
                )
        self.PatchAuthenticatedUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/PatchAuthenticatedUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.FromString,
                )
        self.ListUsers = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListUsers',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.FromString,
                )
        self.GetUser = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetUser',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.FromString,
                )
        self.CreateOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CreateOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.FromString,
                )
        self.ListOrganizations = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListOrganizations',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.FromString,
                )
        self.GetOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.FromString,
                )
        self.UpdateOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.FromString,
                )
        self.DeleteOrganization = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganization',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.FromString,
                )
        self.ListUserMemberships = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListUserMemberships',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.FromString,
                )
        self.GetUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.FromString,
                )
        self.UpdateUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.FromString,
                )
        self.DeleteUserMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteUserMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.FromString,
                )
        self.ListOrganizationMemberships = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListOrganizationMemberships',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.FromString,
                )
        self.GetOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.FromString,
                )
        self.UpdateOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.FromString,
                )
        self.DeleteOrganizationMembership = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganizationMembership',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.FromString,
                )
        self.GetAuthenticatedUserSubscription = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUserSubscription',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.FromString,
                )
        self.GetOrganizationSubscription = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationSubscription',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.FromString,
                )
        self.CreateToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CreateToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.FromString,
                )
        self.ListTokens = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListTokens',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.FromString,
                )
        self.GetToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.FromString,
                )
        self.DeleteToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/DeleteToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.FromString,
                )
        self.ValidateToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ValidateToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.FromString,
                )
        self.GetRemainingCredit = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetRemainingCredit',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.FromString,
                )
        self.CheckNamespace = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/CheckNamespace',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.FromString,
                )
        self.GetPipelineTriggerCount = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/GetPipelineTriggerCount',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.FromString,
                )
        self.ListPipelineTriggerTableRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerTableRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.FromString,
                )
        self.ListPipelineTriggerChartRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerChartRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.FromString,
                )
        self.ListCreditConsumptionChartRecords = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/ListCreditConsumptionChartRecords',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.FromString,
                )
        self.AuthTokenIssuer = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthTokenIssuer',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.FromString,
                )
        self.AuthLogin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthLogin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.FromString,
                )
        self.AuthLogout = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthLogout',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.FromString,
                )
        self.AuthChangePassword = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthChangePassword',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.FromString,
                )
        self.AuthValidateAccessToken = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPublicService/AuthValidateAccessToken',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.FromString,
                )


class MgmtPublicServiceServicer(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    def Liveness(self, request, context):
        """Check if the MGMT server is alive

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Check if the pipeline server is ready

        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthenticatedUser(self, request, context):
        """Get the authenticated user

        Returns the details of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PatchAuthenticatedUser(self, request, context):
        """Update the authenticated user

        Updates the information of the authenticated user.

        In REST requests, only the supplied user fields will be taken into account
        when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUsers(self, request, context):
        """List users

        Returns a paginated list of users.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get a user

        Returns the details of a user by their ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateOrganization(self, request, context):
        """Create an organization

        Creates an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizations(self, request, context):
        """List organizations

        Returns a paginated list of organizations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganization(self, request, context):
        """Get an organization

        Returns the organization details by its ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganization(self, request, context):
        """Update an organization

        Accesses and updates an organization by ID.

        In REST requests, only the supplied organization fields will be taken into
        account when updating the resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganization(self, request, context):
        """Delete an organization

        Accesses and deletes an organization by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserMemberships(self, request, context):
        """List user memberships

        Returns the memberships of a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserMembership(self, request, context):
        """Get a user membership

        Returns the details of the relationship between a user and an
        organization. The authenticated must match the membership parent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateUserMembership(self, request, context):
        """Update a user membership

        Accesses and updates a user membership by parent and membership IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserMembership(self, request, context):
        """Delete a user membership

        Accesses and deletes a user membership by parent and membership IDs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationMemberships(self, request, context):
        """List organization memberships

        Returns a paginated list of the user memberships in an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationMembership(self, request, context):
        """Get a an organization membership

        Returns the details of a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateOrganizationMembership(self, request, context):
        """Uppdate an organization membership

        Updates a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteOrganizationMembership(self, request, context):
        """Delete an organization membership

        Deletes a user membership within an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAuthenticatedUserSubscription(self, request, context):
        """Get the subscription of the authenticated user

        Returns the subscription details of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSubscription(self, request, context):
        """Get the subscription of an organization

        Returns the subscription details of an organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateToken(self, request, context):
        """Create an API token

        Creates an API token for the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTokens(self, request, context):
        """List API tokens

        Returns a paginated list of the API tokens of the authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToken(self, request, context):
        """Get an API token

        Returns the details of an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteToken(self, request, context):
        """Delete an API token

        Deletes an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateToken(self, request, context):
        """Validate an API token

        Validates an API token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRemainingCredit(self, request, context):
        """Get the remaining Instill Credit

        This endpoint returns the remaining [Instill Credit](https://www.instill.tech/docs/vdp/credit) of a given user or
        organization. The requested credit owner must be either the authenticated
        user or an organization they belong to.

        On Instill Core, this endpoint will return a 404 Not Found status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNamespace(self, request, context):
        """Check if a namespace is in use

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPipelineTriggerCount(self, request, context):
        """Get pipeline trigger count

        Returns the pipeline trigger count of a given requester within a timespan.
        Results are grouped by trigger status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipelineTriggerTableRecords(self, request, context):
        """List pipeline trigger metrics

        Returns a paginated list of pipeline executions aggregated by pipeline ID.
        NOTE: This method is deprecated and will be retired soon.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPipelineTriggerChartRecords(self, request, context):
        """List pipeline trigger time charts

        Returns a timeline of pipline trigger counts for the pipelines of a given
        owner.
        NOTE: This method will soon return the trigger counts of a given requester.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCreditConsumptionChartRecords(self, request, context):
        """List Instill Credit consumption time charts

        Returns a timeline of Instill Credit consumption for a given owner. The
        response will contain one set of records (datapoints) per consumption
        source (e.g. "pipeline", "model"). Each datapoint represents the amount
        consumed in a time bucket.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthTokenIssuer(self, request, context):
        """Auth endpoints are only used in the community edition and the OpenAPI
        documentation references Instill Cloud. Therefore, these endpoints are
        hidden.

        Get Auth token issuer

        Returns the auth token issuer details. This operation requires admin permissions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthLogin(self, request, context):
        """Log in a user

        Authenticates a user and returns an access token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthLogout(self, request, context):
        """Log out a user

        Logs out an authenticated user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthChangePassword(self, request, context):
        """Change password

        Updates the password of a user.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AuthValidateAccessToken(self, request, context):
        """Validate an access token

        Checks the validity of an access token.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MgmtPublicServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.SerializeToString,
            ),
            'GetAuthenticatedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthenticatedUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.SerializeToString,
            ),
            'PatchAuthenticatedUser': grpc.unary_unary_rpc_method_handler(
                    servicer.PatchAuthenticatedUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.SerializeToString,
            ),
            'ListUsers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsers,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.SerializeToString,
            ),
            'CreateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.SerializeToString,
            ),
            'ListOrganizations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizations,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.SerializeToString,
            ),
            'GetOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.SerializeToString,
            ),
            'UpdateOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.SerializeToString,
            ),
            'DeleteOrganization': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganization,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.SerializeToString,
            ),
            'ListUserMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserMemberships,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.SerializeToString,
            ),
            'GetUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.SerializeToString,
            ),
            'UpdateUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.SerializeToString,
            ),
            'DeleteUserMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.SerializeToString,
            ),
            'ListOrganizationMemberships': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationMemberships,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.SerializeToString,
            ),
            'GetOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.SerializeToString,
            ),
            'UpdateOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.SerializeToString,
            ),
            'DeleteOrganizationMembership': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteOrganizationMembership,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.SerializeToString,
            ),
            'GetAuthenticatedUserSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthenticatedUserSubscription,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.SerializeToString,
            ),
            'GetOrganizationSubscription': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSubscription,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.SerializeToString,
            ),
            'CreateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.SerializeToString,
            ),
            'ListTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTokens,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.SerializeToString,
            ),
            'GetToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.SerializeToString,
            ),
            'DeleteToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.SerializeToString,
            ),
            'ValidateToken': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.SerializeToString,
            ),
            'GetRemainingCredit': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRemainingCredit,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.SerializeToString,
            ),
            'CheckNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNamespace,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.SerializeToString,
            ),
            'GetPipelineTriggerCount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPipelineTriggerCount,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.SerializeToString,
            ),
            'ListPipelineTriggerTableRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelineTriggerTableRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.SerializeToString,
            ),
            'ListPipelineTriggerChartRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPipelineTriggerChartRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.SerializeToString,
            ),
            'ListCreditConsumptionChartRecords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCreditConsumptionChartRecords,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.SerializeToString,
            ),
            'AuthTokenIssuer': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthTokenIssuer,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.SerializeToString,
            ),
            'AuthLogin': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthLogin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.SerializeToString,
            ),
            'AuthLogout': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthLogout,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.SerializeToString,
            ),
            'AuthChangePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthChangePassword,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.SerializeToString,
            ),
            'AuthValidateAccessToken': grpc.unary_unary_rpc_method_handler(
                    servicer.AuthValidateAccessToken,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.mgmt.v1beta.MgmtPublicService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MgmtPublicService(object):
    """MGMT

    MgmtPublicService exposes the public Core endpoints that allow clients to
    manage user resources.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/Liveness',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/Readiness',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthenticatedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PatchAuthenticatedUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/PatchAuthenticatedUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.PatchAuthenticatedUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUsers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListUsers',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetUser',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CreateOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListOrganizations',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganization(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganization',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListUserMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListUserMemberships',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUserMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteUserMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteUserMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteUserMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationMemberships(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListOrganizationMemberships',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/UpdateOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.UpdateOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteOrganizationMembership(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteOrganizationMembership',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteOrganizationMembershipResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAuthenticatedUserSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetAuthenticatedUserSubscription',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetAuthenticatedUserSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSubscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetOrganizationSubscription',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CreateToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CreateTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListTokens',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/DeleteToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.DeleteTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ValidateToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ValidateToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ValidateTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRemainingCredit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetRemainingCredit',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/CheckNamespace',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPipelineTriggerCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/GetPipelineTriggerCount',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.GetPipelineTriggerCountResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipelineTriggerTableRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerTableRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerTableRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPipelineTriggerChartRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListPipelineTriggerChartRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListPipelineTriggerChartRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCreditConsumptionChartRecords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/ListCreditConsumptionChartRecords',
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_metric__pb2.ListCreditConsumptionChartRecordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthTokenIssuer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthTokenIssuer',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthTokenIssuerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthLogin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthLogin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLoginResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthLogout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthLogout',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthLogoutResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthChangePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthChangePassword',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthChangePasswordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AuthValidateAccessToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPublicService/AuthValidateAccessToken',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.AuthValidateAccessTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
